==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/sq.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Veprimtari",
    "Error loading activities" : "Gabim në ngarkimin e veprimtarive",
    "No activities" : "Asnjë veprimtari",
    "Load more activities" : "Ngarko më tepër veprimtari",
    "Copied!" : "U kopjua!",
    "Not supported!" : "Nuk suportohet!",
    "Press ⌘-C to copy." : "Shtyp ⌘-C për të kopjuar.",
    "Press Ctrl-C to copy." : "Shtyp Ctrl-C për të kopjuar.",
    "{name} (invisible)" : "{emri} (i padukshëm)",
    "{name} (restricted)" : "{emri} (i kufizuar)",
    "in {path}" : "në {rruga}",
    "This stream will show events like additions, changes & shares" : "Kjo rrjedhë do të shfaqë veprimtari të tilla si shtime, ndryshime & ndarje me të tjerë",
    "There are no events for this filter" : "S’ka veprimtari për këtë filtër",
    "Today" : "Sot",
    "Yesterday" : "Dje",
    "Activity" : "Veprimtari",
    "Personal activity feed for %s" : "Prurje veprimtarie personale për  %s",
    "Your feed URL is invalid" : "URL-ja për prurjen tuaj është e pavlefshme",
    "Your settings have been updated." : "Rregullimet tuaja u përditësuan",
    "Mail" : "Posta",
    "Stream" : "Rrjedhë",
    "All activities" : "Të gjitha aktivitetet",
    "By others" : "Nga të tjerët",
    "By you" : "Nga ju",
    "\"remote user\"" : "\"përdorues i largët\"",
    "Activity notification" : "Njoftim veprimtarie",
    ", " : ",",
    "%s and %s" : "%s dhe %s",
    "Hello %s," : "Tungjatjeta %s,",
    "You are receiving this email because the following things happened at %s" : "Këtë email po e merrni ngaqë ndodhën gjërat vijuese te %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* dhe %n më tepër","* dhe %n më tepër"],
    "List your own actions in the stream" : "Listo veprimet e tua në rrjedhë",
    "Notify about your own actions via email" : "Njoftoni me email mbi veprimet tuaja",
    "You need to set up your email address before you can receive notification emails." : "Kërkohet të caktoni adresën tuaj email, përpara se të mund të merrni email-e njoftimesh.",
    "Send emails:" : "Dërgo email-e:",
    "Hourly" : "Çdo orë",
    "Daily" : "Përditë",
    "Weekly" : "Çdo javë",
    "Activity feed" : "Prurje veprimtarie",
    "Enable RSS feed" : "Aktivizoni Prurje RSS",
    "No activity yet" : "Ende pa veprimtari",
    "No more events to load" : "S’ka më veprimtari për t’u ngarkuar",
    "Files" : "Skedar"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/sq.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Veprimtaritë",
    "An error occurred while loading activities" : "Ndodhi një gabim gjatë ngarkimit të aktiviteteve",
    "No activity yet" : "Ende pa veprimtari",
    "Load more activities" : "Ngarko më tepër veprimtari",
    "Copied!" : "U kopjua!",
    "Not supported!" : "Nuk suportohet!",
    "Press ⌘-C to copy." : "Shtyp ⌘-C për të kopjuar.",
    "Press Ctrl-C to copy." : "Shtyp Ctrl-C për të kopjuar.",
    "{name} (invisible)" : "{emri} (i padukshëm)",
    "{name} (restricted)" : "{emri} (i kufizuar)",
    "in {path}" : "në {rruga}",
    "This stream will show events like additions, changes & shares" : "Kjo rrjedhë do të shfaqë veprimtari të tilla si shtime, ndryshime & ndarje me të tjerë",
    "There are no events for this filter" : "S’ka veprimtari për këtë filtër",
    "Today" : "Sot",
    "Yesterday" : "Dje",
    "Personal activity feed for %s" : "Prurje veprimtarie personale për  %s",
    "Your feed URL is invalid" : "URL-ja për prurjen tuaj është e pavlefshme",
    "Your settings have been updated." : "Rregullimet tuaja u përditësuan",
    "Settings have been updated." : "Konfigurimet u përditësuan.",
    "Mail" : "Posta",
    "Stream" : "Rrjedhë",
    "All activities" : "Të gjitha aktivitetet",
    "By others" : "Nga të tjerët",
    "By you" : "Nga ju",
    "\"remote user\"" : "\"përdorues i largët\"",
    "Hello %s" : "Përshëndetje %s",
    "Hello %s," : "Tungjatjeta %s,",
    "There was some activity at %s" : "Pati disa aktivitete te %s",
    "_and %n more _::_and %n more _" : ["dhe %n më tepër ","* dhe %n më tepër"],
    "Activity notification" : "Njoftim veprimtarie",
    ", " : ",",
    "%s and %s" : "%s dhe %s",
    "Activity" : "Veprimtari",
    "Activity feed" : "Prurje veprimtarie",
    "Configure the default activity settings for new users." : "Vendosni konfigurimet fillestare të aktiviteteve për përdoruesit e rinj",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Zgjidhni se për cilat aktivitete doni të merrni njoftime me email, dhe cilat duhet të shfaqen në daljen e aplikacionit të aktiviteteve.",
    "List your own actions in the stream" : "Listo veprimet e tua në rrjedhë",
    "Notify about your own actions via email" : "Njoftoni me email mbi veprimet tuaja",
    "You need to set up your email address before you can receive notification emails." : "Kërkohet të caktoni adresën tuaj email, përpara se të mund të merrni email-e njoftimesh.",
    "Send emails:" : "Dërgo email-e:",
    "Hourly" : "Çdo orë",
    "Daily" : "Përditë",
    "Weekly" : "Çdo javë",
    "Settings" : "Konfigurimet",
    "Enable RSS feed" : "Aktivizoni Prurje RSS",
    "No more events to load" : "S’ka më veprimtari për t’u ngarkuar",
    "Files" : "Skedar",
    "Error loading activities" : "Gabim në ngarkimin e veprimtarive",
    "No activities" : "Asnjë veprimtari",
    "You are receiving this email because the following things happened at %s" : "Ju po e merrni këtë email sepse gjërat në vijim ndodhën në %s",
    "* %1$s - %2$s" : "%1$s-%2$s",
    "_* and %n more _::_* and %n more _" : ["*dhe %n më shumë","*dhe %n më shumë"]
},
"nplurals=2; plural=(n != 1);");
